# unitorch.cli.models.peft

## BloomAdaLoraForClassification

!!! tip
    **`core/model/classification/peft/adalora/bloom`** is the section for configuration of BloomAdaLoraForClassification.

::: unitorch.cli.models.peft.BloomAdaLoraForClassification

## BloomAdaLoraForGeneration

!!! tip
    **`core/model/generation/peft/adalora/bloom`** is the section for configuration of BloomAdaLoraForGeneration.

::: unitorch.cli.models.peft.BloomAdaLoraForGeneration

## BloomLoraForClassification

!!! tip
    **`classification/peft/lora/bloom`** is the section for configuration of BloomLoraForClassification.

::: unitorch.cli.models.peft.BloomLoraForClassification
    
## BloomLoraForGeneration

!!! tip
    **`core/model/generation/peft/lora/bloom`** is the section for configuration of BloomLoraForGeneration.

::: unitorch.cli.models.peft.BloomLoraForGeneration

## LlamaAdaLoraForClassification

!!! tip
    **`core/model/classification/peft/adalora/llama`** is the section for configuration of LlamaAdaLoraForClassification.

::: unitorch.cli.models.peft.LlamaAdaLoraForClassification

## LlamaAdaLoraForGeneration

!!! tip
    **`core/model/generation/peft/adalora/llama`** is the section for configuration of LlamaAdaLoraForGeneration.

::: unitorch.cli.models.peft.LlamaAdaLoraForGeneration

## LlamaLoraForClassification

!!! tip
    **`core/model/classification/peft/lora/llama`** is the section for configuration of LlamaLoraForClassification.

::: unitorch.cli.models.peft.LlamaLoraForClassification
    
## LlamaLoraForGeneration

!!! tip
    **`core/model/generation/peft/lora/llama`** is the section for configuration of LlamaLoraForGeneration.

::: unitorch.cli.models.peft.LlamaLoraForGeneration
